package com.contentsquare.flutter.infrastructure.core

import android.view.View

/**
 * Class that helps to create the target view path used by the Flutter screen graph nodes as root.
 */
internal class TargetViewPathCreator {
    private val flutterTVPSeparator = "|flutter|"

    /**
     * Creates a target view path.
     *
     * Remove the name of the [flutterRenderView] in the [nativeViewPath] to ensure
     * that the path will look like `FlutterView:eq(0)|flutter` as it is in the Gesture events.
     */
    fun create(flutterRenderView: View, nativeViewPath: String): String {
        val name = flutterRenderView.javaClass.simpleName
        return nativeViewPath.removeSuffix(">$name:eq(0)") + flutterTVPSeparator
    }
}