package com.contentsquare.flutter.infrastructure.core.method_call_executor.agents

import com.contentsquare.flutter.infrastructure.core.method_call_executor.data.ExecutionData
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.ExecutionResponse
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.FailedExecutionResponse
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.FailedExecutionResponseReason
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.SuccessExecutionResponse
import com.contentsquare.flutter.infrastructure.proxies.SendCrashReportProxy
import com.contentsquare.flutter.infrastructure.proxies.SendSessionReplayEventProxy

/**
 * Allows to send a session replay event to Contentsquare Native SDK.
 */
internal class SendCrashReportAgent(private val proxy: SendCrashReportProxy = SendCrashReportProxy.default()): MethodCallAgent(nativeExceptionMessage) {

    companion object {
        /** Message to use in case of error during native call. */
        const val nativeExceptionMessage = "Failed to send crash report"

        /** Message in case of "reports" parameter missing. */
        const val missingReportsMessage = "Missing data for reports key"
    }

    override fun execute(data: ExecutionData): ExecutionResponse {
        val reports = data.call.argument<List<ByteArray>>("reports")
            ?: return FailedExecutionResponse(FailedExecutionResponseReason.MISSING_ARGUMENT, missingReportsMessage, null)

        proxy.send(reports)

        return SuccessExecutionResponse.empty()
    }

}