package android.src.main.kotlin.com.contentsquare.flutter.infrastructure.core.states

import android.content.Context
import android.content.pm.PackageInfo
import android.os.Build

class AppInfoProvider {
    companion object {
        private const val KEY_PACKAGE_NAME = "packageName"
        private const val KEY_VERSION = "version"
        private const val KEY_BUILD_NUMBER = "buildNumber"

        fun get(context: Context): Map<String, Any> {
            val packageManager = context.packageManager
            val packageName = context.packageName
            val info = packageManager.getPackageInfo(packageName, 0)
            val version = info.versionName ?: ""
            val buildNumber = getLongVersionCode(info).toString()

            return mapOf(
                KEY_PACKAGE_NAME to packageName,
                KEY_VERSION to version,
                KEY_BUILD_NUMBER to buildNumber
            )
        }

        private fun getLongVersionCode(info: PackageInfo): Long {
            return if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.P) {
                info.longVersionCode
            } else {
                (info.versionCode ?: 0).toLong()
            }
        }
    }
}