package com.contentsquare.flutter.infrastructure.proxies

import ChannelConst
import com.contentsquare.flutter.infrastructure.bridges.ContentsquareSDKBridge
import io.flutter.plugin.common.MethodChannel

/**
 * Allows to listen to the session replay link change event from Contentsquare API.
 */
internal interface OnSessionReplayLinkChangeProxy {
    /**
     * Listen to the session replay link change event from contentsquare API.
     */
    fun onSessionReplayLinkChange()

    companion object Factory {
        /**
         * Creates a new instance of the default implementation of [OnSessionReplayLinkChangeProxy].
         */
        fun default(contentsquareSDK: ContentsquareSDKBridge = ContentsquareSDKBridge.getInstance(), channel: MethodChannel): OnSessionReplayLinkChangeProxy {
            return OnSessionReplayLinkChangeProxyImpl(contentsquareSDK = contentsquareSDK, channel = channel)
        }
    }
}

/**
 * An implementation of [OnSessionReplayLinkChangeProxy].
 *
 * @see OnSessionReplayLinkChangeProxy
 *
 * @property contentsquareSDK The contentsquare SDK bridge.
 * @property channel The method channel.
 */
internal class OnSessionReplayLinkChangeProxyImpl(private val contentsquareSDK: ContentsquareSDKBridge, private val channel: MethodChannel): OnSessionReplayLinkChangeProxy {
    override fun onSessionReplayLinkChange() {

        contentsquareSDK.onSessionReplayLinkChange { link ->
            channel.invokeMethod(ChannelConst.Method.REQUEST_SESSION_REPLAY_URL_CHANGE, mapOf(ChannelConst.Key.SESSION_REPLAY_URL to link))
        }

    }
}