/// `SendCrashReportAgent` used to execute send crash report.
class SendCrashReportAgent: MethodCallAgent {
    
    internal init(proxy: SendCrashReportProxy = SendCrashReportProxyFactory.makeDefault()) {
        self._proxy = proxy
    }
    
    /// Message to use in case of error during native call.
    static let exceptionMessage = "Failed to send crash report"
    
    /// Message in case of "reports" parameter missing
    static let missingReportsMessage = "Missing data for reports key"
    
    private let _proxy: SendCrashReportProxy
    
    var nativeExceptionMessage: String? {
        return SendCrashReportAgent.exceptionMessage
    }
    
    func execute(data: ExecutionData) throws -> ExecutionResponse {
        let arguments: [String: Any] = data.call.arguments as? [String: Any] ?? [:]
        guard let flutterDataReports = arguments["reports"] as? [FlutterStandardTypedData] else {
            throw FailedExecutionError(
                reason: FailedExecutionResponseReason.missingArgument, message: SendCrashReportAgent.missingReportsMessage,
                cause: nil
            )
        }

        let dataReports: [Data] = flutterDataReports.map { flutterTypedData in
            return flutterTypedData.data
        }
        
        try _proxy.send(reports: dataReports)
        
        return ExecutionResponse.succeed(result: nil)
    }
}
